@@ -69,6 +69,7 @@ struct _GstRTSPSessionPrivate
 #undef DEBUG
 
 #define DEFAULT_TIMEOUT	       60
+#define NO_TIMEOUT              -1
 #define DEFAULT_ALWAYS_VISIBLE  FALSE
 
 enum
@@ -319,7 +320,7 @@ gst_rtsp_session_release_media (GstRTSPSession * sess,
  * Get the session media for @path. @matched will contain the number of matched
  * characters of @path.
  *
- * Returns: (transfer none): the configuration for @path in @sess.
+ * Returns: (transfer none) (nullable): the configuration for @path in @sess.
  */
 GstRTSPSessionMedia *
 gst_rtsp_session_get_media (GstRTSPSession * sess, const gchar * path,
@@ -479,8 +480,8 @@ gst_rtsp_session_new (const gchar * sessionid)
  *
  * Get the sessionid of @session.
  *
- * Returns: (transfer none): the sessionid of @session. The value remains valid
- * as long as @session is alive.
+ * Returns: (transfer none) (nullable): the sessionid of @session.
+ * The value remains valid as long as @session is alive.
  */
 const gchar *
 gst_rtsp_session_get_sessionid (GstRTSPSession * session)
@@ -496,7 +497,8 @@ gst_rtsp_session_get_sessionid (GstRTSPSession * session)
  *
  * Get the string that can be placed in the Session header field.
  *
- * Returns: (transfer full): the Session header of @session. g_free() after usage.
+ * Returns: (transfer full) (nullable): the Session header of @session.
+ * g_free() after usage.
  */
 gchar *
 gst_rtsp_session_get_header (GstRTSPSession * session)
@@ -634,6 +636,14 @@ gst_rtsp_session_next_timeout_usec (GstRTSPSession * session, gint64 now)
 
   priv = session->priv;
 
+  g_mutex_lock (&priv->lock);
+  /* If timeout is set to 0, we never timeout */
+  if (priv->timeout == 0) {
+    g_mutex_unlock (&priv->lock);
+    return NO_TIMEOUT;
+  }
+  g_mutex_unlock (&priv->lock);
+
   g_mutex_lock (&priv->last_access_lock);
   if (g_atomic_int_get (&priv->expire_count) != 0) {
     /* touch session when the expire count is not 0 */
@@ -672,10 +682,6 @@ gst_rtsp_session_next_timeout_usec (GstRTSPSession * session, gint64 now)
  * Deprecated: Use gst_rtsp_session_next_timeout_usec() instead.
  */
 #ifndef GST_REMOVE_DEPRECATED
-#ifdef GST_DISABLE_DEPRECATED
-gint gst_rtsp_session_next_timeout (GstRTSPSession * session, GTimeVal * now);
-#endif
-
 gint
 gst_rtsp_session_next_timeout (GstRTSPSession * session, GTimeVal * now)
 {
@@ -747,15 +753,13 @@ gst_rtsp_session_is_expired_usec (GstRTSPSession * session, gint64 now)
  * Deprecated: Use gst_rtsp_session_is_expired_usec() instead.
  */
 #ifndef GST_REMOVE_DEPRECATED
-#ifdef GST_DISABLE_DEPRECATED
-gboolean gst_rtsp_session_is_expired (GstRTSPSession * session, GTimeVal * now);
-#endif
 gboolean
 gst_rtsp_session_is_expired (GstRTSPSession * session, GTimeVal * now)
 {
   gboolean res;
 
-  res = (gst_rtsp_session_next_timeout (session, now) == 0);
+  res = gst_rtsp_session_next_timeout_usec (session,
+      (now->tv_sec * G_USEC_PER_SEC) + (now->tv_usec));
 
   return res;
 }
